@@ -8,15 +8,15 @@ class StateMachine():
 
     Example
     -------
-    # Contextクラス、state_creator_dictディクショナリー, transition_dictディクショナリー は別途作っておいてください
+    # Context クラス、 state_gen ディクショナリー、 transition ディクショナリー は別途作っておいてください
 
     context = Context()
-    sm = StateMachine(context, state_creator_dict=state_creator_dict, transition_dict=transition_dict)
+    sm = StateMachine(context, state_gen=state_gen, transition=transition)
 
     sm._arrive("[Init]") # Init状態は作っておいてください
     """
 
-    def __init__(self, context=None, state_creator_dict={}, transition_dict={}, intermachine=None, name=None):
+    def __init__(self, context=None, state_gen={}, transition={}, intermachine=None, name=None):
         """初期化
 
         Parameters
@@ -24,14 +24,14 @@ class StateMachine():
         context : Context
             このステートマシンは、このContextが何なのか知りません。
             外部から任意に与えることができる変数です。 Defaults to None.
-        state_creator_dict : dict
+        state_gen : dict
             状態を作成する関数のディクショナリーです。 Defaults to {}.
-        transition_dict : dict
+        transition : dict
             遷移先の状態がまとめられたディクショナリーです。 Defaults to {}.
         """
         self._context = context
-        self._state_creator_dict = state_creator_dict
-        self._transition_dict = transition_dict
+        self._state_gen = state_gen
+        self._transition = transition
         self._verbose = False
         self._edge_path = []
         self._lines_getter = None  # 標準入力とか１個しかないけど
@@ -238,9 +238,9 @@ class StateMachine():
             print(
                 f"{self._alternate_state_machine_name()} Arrive to {next_state_name} {edge_path}")
 
-        if next_state_name in self._state_creator_dict:
+        if next_state_name in self._state_gen:
             # 次のステートへ引継ぎ
-            self._state = self._state_creator_dict[next_state_name]()
+            self._state = self._state_gen[next_state_name]()
 
         else:
             # Error
@@ -296,8 +296,8 @@ class StateMachine():
         # None かもしれません。
 
         # まずはカレントステートを指定してディクショナリーを取ってきましょう
-        if self.state.name in self._transition_dict:
-            curr_dict = self._transition_dict[self.state.name]
+        if self.state.name in self._transition:
+            curr_dict = self._transition[self.state.name]
             if curr_dict is None:
                 self.terminate()
                 return
